/*

 $Id: shellOutputDlg.h,v 1.10 2004/05/26 10:38:08 pinto Exp $

 ark -- archiver for the KDE project

 Copyright (C)

 1997-1999: Rob Palmbos palm9744@kettering.edu
 1999: Francois-Xavier Duranceau duranceau@kde.org

 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation; either version 2
 of the License, or (at your option) any later version.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

*/

#ifndef SHELL_OUTPUT_DLG_H
#define SHELL_OUTPUT_DLG_H

#include <kdialogbase.h>

class QWidget;
class QString;
class QTextEdit;

class ShellOutputDlg : public KDialogBase
{
	Q_OBJECT
	public:
		ShellOutputDlg( const QString& text, QWidget *parent=0, const char *name=0 );
		~ShellOutputDlg();
	private:
		QTextEdit * m_outputViewer;
};

#endif /* SHELL_OUTPUT_DLG_H */

